# Global variable declarations for R CMD check
# These are column names used in dplyr/ggplot2 NSE

utils::globalVariables(c(
 # Column names used in dplyr operations
 "athlete_id",
 "country",
 "display_name",
 "event_id",
 "hole",
 "par",
 "player",
 "player_id",
 "player_name",
 "position",
 "rounds",
 "score",
 "score_display",
 "score_type",
 "sg_app",
 "sg_arg",
 "sg_ott",
 "sg_putt",
 "sg_t2g",
 "sg_total",
 "strokes_gained",
 "total_score",
 "tournament_id",
 "tournament_name",
 "tournament_num",
 "wins"
))
